| Title: | Creates Synonyms From Target Words |
|---|---|
| Description: | Generates synonyms from a given word drawing from a synonym list from the 'moby' project <http://moby-thesaurus.org/>. |
| Authors: | Nicholas Tierney [aut, cre] (ORCID: <https://orcid.org/0000-0003-1460-8722>), Amy Stringer [aut] (ORCID: <https://orcid.org/0000-0002-0409-7976>), Mike Cheng [aut], Laura de Jong [aut], Thomas Lumley [ctb] |
| Maintainer: | Nicholas Tierney <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-05-08 08:44:31 UTC |
| Source: | https://github.com/njtierney/syn |
Ant: Get antonyms for one word
ant(word, n_words = -1)ant(word, n_words = -1)
word |
character, one word you want to find antonyms for. |
n_words |
integer, the number of words to return. |
antonyms of the word you entered. Returns character(0) if word not found
ant("good") ant("evil", 25) # No words for spelling mistakes ant("spolling misteak")ant("good") ant("evil", 25) # No words for spelling mistakes ant("spolling misteak")
Ants: Get antonyms for many words
ants(words, n_words = -1)ants(words, n_words = -1)
words |
word, character - many words you want to find antonyms. |
n_words |
integer, the number of words to look for. |
named list of antonyms. Returns character(0) if word not found
ants(c("good", "evil"), 10)ants(c("good", "evil"), 10)
Return the number of words in a string
n_words(x)n_words(x)
x |
a string |
vector of numbers
syn_end <- syn("end") syn_end_words <- n_words(syn_end) syn_end[syn_end_words <= 1]syn_end <- syn("end") syn_end_words <- n_words(syn_end) syn_end[syn_end_words <= 1]
syn provides a dependency free way to get synonyms and antonyms of words.
syn(word, n_words = -1)syn(word, n_words = -1)
word |
character, one word you want to find synonyms for. |
n_words |
integer, the number of words to look for. An integer Default is all words |
synonyms of the word you entered. Returns character(0) if word not found.
Maintainer: Nicholas Tierney [email protected] (ORCID)
Authors:
Amy Stringer [email protected] (ORCID)
Mike Cheng [email protected]
Laura de Jong
Other contributors:
Thomas Lumley [email protected] [contributor]
It's main functions are:
Learn more about syn at https://syn.njtierney.com/
# put some examples here syn("good") syn("evil", 25) # No words for spelling mistakes syn("spolling misteak")# put some examples here syn("good") syn("evil", 25) # No words for spelling mistakes syn("spolling misteak")
Syns: Get synonyms for many words
syns(words, n_words = -1)syns(words, n_words = -1)
words |
word, character - many words you want to find synonyms for |
n_words |
integer, the number of words to look for. An integer Default is all words |
named list of synonyms. Returns character(0) if word not found.
syns(c("good", "evil"), 10) # No words for spelling mistakes syns("spolling misteak")syns(c("good", "evil"), 10) # No words for spelling mistakes syns("spolling misteak")